This is the Python client library for the Tenta Sensor Network management. The repository will soon be published open source at https://github.com/iterize/tenta including this client library.

Client library version `0.X.*` will be compatible with the server version `0.X.*`. Client library versions `Y.*.*` will be compatible with server versions `Y.*.*`.
